@@ -2,49 +2,49 @@
 ### Encoding: ISO8859-1
 
 ###################################################
-### code chunk number 1: dlsem_vignette.Rnw:311-312 (eval = FALSE)
+### code chunk number 1: dlsem_vignette.Rnw:373-374 (eval = FALSE)
 ###################################################
 ## install.packages("dlsem")
 
 
 ###################################################
-### code chunk number 2: dlsem_vignette.Rnw:319-320 (eval = FALSE)
+### code chunk number 2: dlsem_vignette.Rnw:381-382 (eval = FALSE)
 ###################################################
 ## update.packages("dlsem")
 
 
 ###################################################
-### code chunk number 3: dlsem_vignette.Rnw:352-353
+### code chunk number 3: dlsem_vignette.Rnw:414-415
 ###################################################
 require(dlsem)
 
 
 ###################################################
-### code chunk number 4: dlsem_vignette.Rnw:358-360
+### code chunk number 4: dlsem_vignette.Rnw:420-422
 ###################################################
 data(industry)
 summary(industry)
 
 
 ###################################################
-### code chunk number 5: dlsem_vignette.Rnw:400-405
+### code chunk number 5: dlsem_vignette.Rnw:463-468
 ###################################################
 indus.code <- list(
   Job ~ 1,
-  Consum~quec(Job,0,15),
-  Pollution~quec(Job,0,15)+quec(Consum,0,15)
+  Consum~quec.lag(Job,0,15),
+  Pollution~quec.lag(Job,0,15)+quec.lag(Consum,0,15)
   )
 
 
 ###################################################
-### code chunk number 6: dlsem_vignette.Rnw:461-463
+### code chunk number 6: dlsem_vignette.Rnw:524-526
 ###################################################
 indus.global <- list(adapt=T,max.gestation=3,max.lead=15,min.width=5,sign="+")
 indus.local <- list()
 
 
 ###################################################
-### code chunk number 7: dlsem_vignette.Rnw:470-478
+### code chunk number 7: dlsem_vignette.Rnw:533-541
 ###################################################
 indus.global <- list()
 indus.local <- list(
@@ -57,7 +57,7 @@ indus.local <- list(
 
 
 ###################################################
-### code chunk number 8: dlsem_vignette.Rnw:483-489
+### code chunk number 8: dlsem_vignette.Rnw:546-552
 ###################################################
 indus.global <- list(adapt=T,min.width=5)
 indus.local <- list(
@@ -68,74 +68,68 @@ indus.local <- list(
 
 
 ###################################################
-### code chunk number 9: dlsem_vignette.Rnw:541-543
+### code chunk number 9: dlsem_vignette.Rnw:603-605
 ###################################################
 indus.mod <- dlsem(indus.code,group="Region",exogenous=c("Population","GDP"),
   data=industry,global.control=indus.global,local.control=indus.local,log=T)
 
 
 ###################################################
-### code chunk number 10: dlsem_vignette.Rnw:559-560
+### code chunk number 10: dlsem_vignette.Rnw:619-620
 ###################################################
 summary(indus.mod)
 
 
 ###################################################
-### code chunk number 11: dlsem_vignette.Rnw:579-580
-###################################################
-lapply(indus.mod$estimate,summary)
-
-
-###################################################
-### code chunk number 12: dlsem_vignette.Rnw:590-591 (eval = FALSE)
+### code chunk number 11: dlsem_vignette.Rnw:638-639 (eval = FALSE)
 ###################################################
 ## plot(indus.mod)
 
 
 ###################################################
-### code chunk number 13: dlsem_vignette.Rnw:637-638
+### code chunk number 12: dlsem_vignette.Rnw:683-684
 ###################################################
 causalEff(indus.mod,from="Job",to="Pollution",cumul=T)
 
 
 ###################################################
-### code chunk number 14: dlsem_vignette.Rnw:664-666 (eval = FALSE)
+### code chunk number 13: dlsem_vignette.Rnw:706-708 (eval = FALSE)
 ###################################################
 ## lagPlot(indus.mod,path="Job*Pollution")
 ## lagPlot(indus.mod,path="Job*Consum*Pollution")
 
 
 ###################################################
-### code chunk number 15: dlsem_vignette.Rnw:673-674 (eval = FALSE)
+### code chunk number 14: dlsem_vignette.Rnw:715-716 (eval = FALSE)
 ###################################################
 ## lagPlot(indus.mod,from="Job",to="Pollution")
 
 
 ###################################################
-### code chunk number 16: dlsem_vignette.Rnw:705-723
+### code chunk number 15: dlsem_vignette.Rnw:746-764
 ###################################################
 # model 2: quadratic decreasing lag shapes
 indus.code_2 <- list(
   Job ~ 1,
-  Consum~qdec(Job,0,15),
-  Pollution~qdec(Job,0,15)+qdec(Consum,0,15)
+  Consum~qdec.lag(Job,0,15),
+  Pollution~qdec.lag(Job,0,15)+qdec.lag(Consum,0,15)
   )
 indus.mod_2 <- dlsem(indus.code_2,group="Region",exogenous=c("Population","GDP"),
   data=industry,global.control=indus.global,local.control=indus.local,log=T)
-summary(indus.mod_2)
+summary(indus.mod_2)$endogenous
 # model 3: gamma lag shapes
 indus.code_3 <- list(
   Job ~ 1,
-  Consum~gamma(Job,0.5,0.5),
-  Pollution~gamma(Job,0.5,0.5)+gamma(Consum,0.5,0.5)
+  Consum~gamma.lag(Job,0.5,0.5),
+  Pollution~gamma.lag(Job,0.5,0.5)+gamma.lag(Consum,0.5,0.5)
   )
 indus.mod_3 <- dlsem(indus.code_3,group="Region",exogenous=c("Population","GDP"),
   data=industry,global.control=indus.global,local.control=indus.local,log=T)
-summary(indus.mod_3)
+summary(indus.mod_3)$endogenous
 
 
 ###################################################
-### code chunk number 17: dlsem_vignette.Rnw:733-735
+### code chunk number 16: dlsem_vignette.Rnw:774-776
 ###################################################
 lapply(list(QUEC=indus.mod,QDEC=indus.mod_2,GAMMA=indus.mod_3),AIC)
 lapply(list(QUEC=indus.mod,QDEC=indus.mod_2,GAMMA=indus.mod_3),BIC)
